@@ -8,12 +8,14 @@ register = template.Library()
 
 
 @register.inclusion_tag('django_pagarme/pagarme_js_form.html')
-def show_pagarme(payment_item: PagarmeItemConfig, customer: dict = None, address=None, open_modal: bool = False):
+def show_pagarme(payment_item: PagarmeItemConfig, customer: dict = None, address=None, open_modal: bool = False,
+                 review_informations: bool = False):
     notification_path = reverse('django_pagarme:notification', kwargs={'slug': payment_item.slug})
     domain = settings.ALLOWED_HOSTS[0]
     return {
         'payment_item': payment_item,
         'open_modal': open_modal,
+        'review_informations': review_informations,
         'customer': customer,
         'address': address,
         'postback_url': f'https://{domain}{notification_path}',
