@@ -53,10 +53,19 @@ def capture(request, slug, token):
     except facade.PaymentViolation as e:
         logger.exception(str(e))
         return HttpResponseBadRequest()
+    except facade.TokenDifferentFromTransactionIdxception as e:
+        return redirect(
+            reverse('django_pagarme:capture', kwargs={'slug': slug, 'token': e.transaction_id}),
+            permanent=True
+        )
     else:
         if payment.payment_method == facade.BOLETO:
-            ctx = {'payment': payment}
-            return render(request, 'django_pagarme/show_boleto_data.html', ctx)
+            ctx = {'payment': payment, 'upsell': facade.get_payment_item(slug).upsell}
+            suffix = slug.replace('-', '_')
+            try:
+                return render(request, f'django_pagarme/show_boleto_data_{suffix}.html', ctx)
+            except TemplateDoesNotExist:
+                return render(request, 'django_pagarme/show_boleto_data.html', ctx)
         else:
             return redirect(reverse('django_pagarme:thanks', kwargs={'slug': slug}))
 
